%global pname MDAnalysis
%global build_docs 0

%if 0%{?rhel} && 0%{?rhel} <= 6
%{!?__python2: %global __python2 /usr/bin/python2}
%{!?python2_sitelib: %global python2_sitelib %(%{__python2} -c "from distutils.sysconfig import get_python_lib; print(get_python_lib())")}
%{!?python2_sitearch: %global python2_sitearch %(%{__python2} -c "from distutils.sysconfig import get_python_lib; print(get_python_lib(1))")}
%endif

Name: python-%{pname}
Version: 0.16.2
Release: 1%{?dist}
Summary: Analyze and manipulate molecular dynamics trajectories
License: GPLv2+ and BSD and MIT and CC-BY-ND
# BSD:
# MDAnalysis/lib/formats/*/xdrfile*
# MDAnalysis/lib/qcprot.pyx
# MDAnalysis/lib/src/transformations/transformations.c
# MDAnalysis/lib/transformations.py
# MIT:
# MDAnalysisTests-0.16.0/MDAnalysisTests/tempdir.py
# CC-BY-ND:
# doc/sphinx/source/logos
# GPLv2+:
# everything else
URL: http://www.mdanalysis.org
Source0: https://files.pythonhosted.org/packages/source/M/%{pname}/%{pname}-%{version}.tar.gz
Source1: https://files.pythonhosted.org/packages/source/M/%{pname}Tests/%{pname}Tests-%{version}.tar.gz
Source2: https://github.com/%{pname}/mdanalysis/releases/download/release-%{version}/%{pname}Docs-%{version}.zip
# skip a failing test on non-x86_64 arches for now
# https://github.com/MDAnalysis/mdanalysis/issues/1389
Patch1: %{name}-skip-tests-all.patch
# skip some failing tests on 32bit arches for now
# https://github.com/MDAnalysis/mdanalysis/issues/1362
Patch2: %{name}-skip-tests-32bit.patch
# TRZ file reader assumes little-endian arch
# https://github.com/MDAnalysis/mdanalysis/issues/1424
Patch3: %{name}-endian.patch

# we don't want to provide private python extension libs in python2 dirs
%global __provides_exclude_from ^%{python2_sitearch}/.*\\.so$

%global desc \
MDAnalysis is a python framework to analyze molecular dynamics trajectories\
generated by CHARMM, NAMD, LAMMPS, or Gromacs. It is mainly useful for geometric\
analyses, as there is no implemented potential model. \
\
It is inspired by the Schulten Group's MDtools for python, and the source for\
the DCD reading code is derived from VMD. MDAnalysis isGPL licensed, except for\
the dcd reading code (UIUC Open Source Licence) which comes from VMD (and is\
GPL-compatible). Gromacs trajectories are utilizing the Gromacs libxdrfile\
library (GPL). MDAnalysis exposes trajectory data transparently as NumPy arrays\
and as such it is easily extensible.

%description
%{desc}

%package -n python2-%{pname}
Summary: %{summary}
Requires: python2-biopython
Requires: python2-GridDataFormats
Requires: python2-joblib
Requires: python2-matplotlib
Requires: python2-mmtf
Requires: python2-networkx
Requires: python2-numpy
Requires: python2-scipy
# optional deps
# this should also include matplotlib and scipy,
# but their lack is not handled gracefully
# https://github.com/MDAnalysis/mdanalysis/issues/1361
Recommends: python2-netcdf4
Recommends: python2-scikit-learn
Recommends: python2-seaborn
BuildRequires: python2-Cython
BuildRequires: python2-devel
BuildRequires: python2-numpy
BuildRequires: python2-setuptools
%if 0%{?build_docs}
BuildRequires: python2-sphinx
%endif
# for tests
BuildRequires: python2-biopython
BuildRequires: python2-GridDataFormats
BuildRequires: python2-joblib
BuildRequires: python2-matplotlib
BuildRequires: python2-mmtf
BuildRequires: python2-mock
BuildRequires: python2-netcdf4
BuildRequires: python2-networkx
BuildRequires: python2-nose
BuildRequires: python2-psutil
BuildRequires: python2-scikit-learn
BuildRequires: python2-tempdir
# MDAnalysis/coordinates/xdrfile/src
Provides: bundled(xdrfile) = 0.7.7
%{?python_provide:%python_provide python2-%{pname}}

%description -n python2-%{pname}
%{desc}

%package doc
Summary: Documentation for MDAnalysis
BuildArch: noarch
License: CC-BY-ND and GPLv2+

%description doc
MDAnalysis is a python framework to analyze molecular dynamics trajectories
generated by CHARMM, NAMD, LAMMPS, or Gromacs. It is mainly useful for geometric
analyses, as there is no implemented potential model.

This package contains the documentation

%prep
%setup -q -n %{pname}-%{version} -a 1
%ifnarch x86_64
%patch1 -p1 -b .skip-all
%ifarch armv7hl i686
%patch2 -p1 -b .skip-32bit
%endif
%endif
%patch3 -p1 -b .endian
# force rebuild of Egg Metadata
rm -r %{pname}.egg-info
rm -r %{pname}Tests-%{version}/%{pname}Tests.egg-info

%build
%{py2_build}

pushd %{pname}Tests-%{version}
%{py2_build}
popd

%if 0%{?build_docs}
rm -f MDAnalysis.egg-link easy-install.pth
# https://github.com/MDAnalysis/mdanalysis/wiki/WritingDocumentation#build-the-docs-with-sphinx
PYTHONPATH=%{buildroot}%{python2_sitelib}:%{buildroot}%{python2_sitearch}:$PWD \
%{__python2} setup.py develop -d $PWD
%{__python2} setup.py build_sphinx
%else
mkdir -p build/sphinx/html
unzip -qq %{SOURCE2} -d build/sphinx/html
find build/sphinx/html -type d |xargs chmod 755
%endif

%install
%{py2_install}
find %{buildroot}%{python2_sitearch}/%{pname} -type f -name "*.so" | xargs chmod 755

pushd %{pname}Tests-%{version}
%{py2_install}
popd

%check
%if 1
# https://github.com/MDAnalysis/mdanalysis/wiki/UnitTests#recommended
cd %{pname}Tests-%{version}/%{pname}Tests
PYTHONPATH=%{buildroot}%{python2_sitelib}:%{buildroot}%{python2_sitearch} \
 nosetests-%{python2_version} \
 -v \
 --exe \
 --processes=$(getconf _NPROCESSORS_ONLN) \
 --process-timeout=600
%endif

%files -n python2-%{pname}
%license LICENSE
%doc AUTHORS CHANGELOG README SUMMARY.txt
%{python2_sitearch}/%{pname}-%{version}-py%{python2_version}.egg-info
%{python2_sitearch}/%{pname}
%exclude %{python2_sitelib}/%{pname}Tests-%{version}-py%{python2_version}.egg-info
%exclude %{python2_sitelib}/%{pname}Tests

%files doc
%license LICENSE
%doc build/sphinx/html/*

%changelog
* Fri Jun 30 2017 Dominik Mierzejewski <rpm@greysector.net> - 0.16.2-1
- update to 0.16.2
- update doc tarball URL and handling
- drop obsolete patch

* Thu Jun 22 2017 Dominik Mierzejewski <rpm@greysector.net> - 0.16.1-3
- fix endianness issues on BE arches (ppc64, s390x)
- increase test process timeout (was timing out on aarch64)

* Sat Jun 17 2017 Dominik Mierzejewski <rpm@greysector.net> - 0.16.1-2
- backport more fixes from git

* Thu Jun 08 2017 Dominik Mierzejewski <rpm@greysector.net> - 0.16.1-1
- update to 0.16.1
- fix test failures on 32bit

* Thu May 18 2017 Dominik Mierzejewski <rpm@greysector.net> - 0.16.0-1
- update to 0.16.0
- drop obsolete patches
- add new dependencies (joblib, mmtf, mock, psutil)
- fix netcdf4-python dependencies (need python2-netcdf4, actually)
- switch to nosetests while strange test failures are investigated
  (https://github.com/MDAnalysis/mdanalysis/issues/1360)
- add a link to upstream-recommended way of running tests
- modernize python module dependencies

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.14.0-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Mon Sep 26 2016 Dominik Mierzejewski <rpm@greysector.net> - 0.14.0-4
- rebuilt for matplotlib-2.0.0

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.14.0-3
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Tue Mar 15 2016 Dominik Mierzejewski <rpm@greysector.net> 0.14.0-2
- fix non-standard-dir-perm in doc subpackage
- move python2 build to python2-MDAnalysis subpackage
- exclude private libmdaxdr.so from Provides:

* Fri Mar 11 2016 Dominik Mierzejewski <rpm@greysector.net> 0.14.0-1
- update to 0.14.0
- don't build docs for now, upstream published them in a zip file
- drop obsolete patch
- fix tests with numpy 1.11
- fix license field for docs subpackage
- install LICENSE with the doc subpackage as well
- move building of docs to the build section
- use some python-related convenience macros

* Tue Feb 09 2016 Dominik Mierzejewski <rpm@greysector.net> 0.13.0-2
- build docs
- new dependency: seaborn
- omit failing tests on f24 for now

* Mon Feb 08 2016 Dominik Mierzejewski <rpm@greysector.net> 0.13.0-1
- update to 0.13.0
- fix running tests
- add Provides for bundled xdrfile
- docs not included and failing to build, so disable for now

* Wed Oct 14 2015 Dominik Mierzejewski <rpm@greysector.net> 0.12.1-1
- update to 0.12.1
- drop obsolete patch
- use the new mda_nosetests script for running tests

* Mon May 18 2015 Dominik Mierzejewski <rpm@greysector.net> 0.9.2-4
- relax Improper Torsion topology test check on i686

* Mon May 11 2015 Dominik Mierzejewski <rpm@greysector.net> 0.9.2-3
- document licensing breakdown
- package docs

* Fri May 08 2015 Dominik Mierzejewski <rpm@greysector.net> 0.9.2-2
- call the testsuite per upstream docs

* Wed May 06 2015 Dominik Mierzejewski <rpm@greysector.net> 0.9.2-1
- update to 0.9.2
- update upstream URL
- drop obsolete patch
- fix testsuite invocation

* Wed Feb 04 2015 Dominik Mierzejewski <rpm@greysector.net> 0.8.1-1
- initial build
